@@ -30,7 +30,6 @@ use List::Util qw(first);
 use POSIX qw(strftime);
 
 use Lintian::Data;
-use Lintian::Util qw(internal_error);
 
 use Moo;
 use namespace::clean;
@@ -43,12 +42,12 @@ my $ANCIENT_DATE_DATA = Lintian::Data->new(
     qr{\s*<\s*},
     sub {
         my $date = str2time($_[1])
-          or internal_error("Cannot parse ANCIENT_DATE: $!");
+          or die "Cannot parse ANCIENT_DATE: $!";
         return $date;
     });
 
 my $ANCIENT_DATE = $ANCIENT_DATE_DATA->value('ANCIENT')
-  or internal_error('Cannot get ANCIENT_DATE');
+  or die 'Cannot get ANCIENT_DATE';
 
 my $STANDARDS= Lintian::Data->new('standards-version/release-dates', qr/\s+/o);
 
@@ -69,14 +68,15 @@ my @CURRENT      = split(m/\./, $CURRENT);
 sub source {
     my ($self) = @_;
 
-    my $info = $self->info;
+    my $processable = $self->processable;
 
     # udebs aren't required to conform to policy, so they don't need
     # Standards-Version. (If they have it, though, it should be valid.)
-    my $version = $info->field('standards-version');
+    my $version = $processable->field('standards-version');
     my $all_udeb = 1;
     $all_udeb = 0
-      if first { $info->binary_package_type($_) ne 'udeb' } $info->binaries;
+      if first { $processable->binary_package_type($_) ne 'udeb' }
+    $processable->binaries;
 
     if (not defined $version) {
         $self->tag('no-standards-version-field') unless $all_udeb;
@@ -99,8 +99,8 @@ sub source {
     # that the package was released today, since that activates the
     # most tags.
     my ($pkgdate, $dist);
-    if (defined $info->changelog) {
-        my ($entry) = @{$info->changelog->entries};
+    if (defined $processable->changelog) {
+        my ($entry) = @{$processable->changelog->entries};
         $pkgdate
           = ($entry && $entry->Timestamp) ? $entry->Timestamp : $CURRENT_DATE;
         $dist = ($entry && $entry->Distribution)? $entry->Distribution : '';
@@ -138,7 +138,8 @@ sub source {
                 and $minor == $CURRENT[1]
                 and $patch > $CURRENT[2])
         ) {
-            $self->tag('newer-standards-version', $tag);
+            $self->tag('newer-standards-version', $tag)
+              unless $dist =~ /backports/;
         } else {
             $self->tag('invalid-standards-version', $version);
         }
@@ -161,11 +162,11 @@ sub source {
         } else {
             # We have to get the package date from the changelog file.  If we
             # can't find the changelog file, always issue the tag.
-            unless (defined $info->changelog) {
+            unless (defined $processable->changelog) {
                 $self->tag('out-of-date-standards-version', $tag);
                 return;
             }
-            my ($entry) = @{$info->changelog->entries};
+            my ($entry) = @{$processable->changelog->entries};
             my $timestamp
               = ($entry && $entry->Timestamp) ? $entry->Timestamp : 0;
             for my $standard (@STANDARDS) {
