@@ -36,19 +36,19 @@ my $MULTIARCH_DIRS = Lintian::Data->new('common/multiarch-dirs', qr/\s++/);
 sub files {
     my ($self, $file) = @_;
 
-    my $architecture = $self->info->field('architecture', '');
-    my $multiarch = $self->info->field('multi-arch', 'no');
+    my $architecture = $self->processable->field('architecture', '');
+    my $multiarch = $self->processable->field('multi-arch', 'no');
 
     # check old style config scripts
     if (    $file->name =~ m,^usr/bin/,
         and $file->name =~ m,-config$,
-        and $self->info->is_script($file->name)
+        and $file->is_script
         and $file->is_regular_file) {
 
         # try to find some indication of
         # config file (read only one block)
 
-        my $fd = $file->open(':raw');
+        open(my $fd, '<:raw', $file->unpacked_path);
         my $sfd = Lintian::SlidingWindow->new($fd);
         my $block = $sfd->readwindow;
 
