@@ -248,14 +248,21 @@ sub check_test_file {
     } else {
         open(my $fd, '<', $index->unpacked_path);
         while (my $x = <$fd>) {
-            if ($x =~ m/ADTTMP/) {
-                $self->tag('uses-deprecated-adttmp', $path, "(line $.)");
-                last;
-            }
+            $self->tag('uses-deprecated-adttmp', $path, "(line $.)")
+              if $x =~ m/ADTTMP/;
+            $self->tag('runtime-test-file-uses-installed-python-versions',
+                $path, "$1", "(line $.)")
+              if $x =~ m/(py3versions\s+([\w\-\s]*--installed|-\w*i\w*))/;
+            #<<< no Perl tidy
+            $self->tag(
+                'runtime-test-file-uses-supported-python-versions-without-python-all-build-depends',
+                $path, "$1", "(line $.)"
+            ) if $x =~ m/(py3versions\s+([\w\-\s]*--supported|-\w*s\w*))/
+              and not $processable->relation('build-depends-all')->implies('python3-all');
+            #>>>
         }
         close($fd);
     }
-    # Test files are allowed not to be executable.
     return;
 }
 
