@@ -37,7 +37,8 @@ use List::MoreUtils qw(first_index);
 use POSIX qw(strftime);
 
 use Lintian::Command qw(safe_qx);
-use Lintian::Util qw(find_backlog load_state_cache save_state_cache untaint);
+use Lintian::Reporting::Util
+  qw(find_backlog load_state_cache save_state_cache);
 
 my (@LINTIAN_CMD, $LINTIAN_VERSION);
 
@@ -71,6 +72,17 @@ sub main {
 
 ### END OF SCRIPT -- below are helper subroutines ###
 
+=item untaint(VALUE)
+
+Untaint VALUE
+
+=cut
+
+sub untaint {
+    return $_[0] = $1 if $_[0] =~ m/^(.*)$/;
+    return;
+}
+
 sub check_parameters {
     for my $parameter (@REQUIRED_PARAMETERS) {
         if (not defined($OPT{$parameter})) {
