@@ -26,7 +26,6 @@ use warnings::register;
 use Carp qw(croak);
 use Path::Tiny;
 
-use Lintian::Collect::Dispatcher qw(create_info);
 use Lintian::Util qw(get_dsc_info get_deb_info);
 
 use constant EMPTY => q{};
@@ -62,7 +61,7 @@ Lintian::Processable -- An (abstract) object that Lintian can process
 
 Instances of this perl class are objects that Lintian can process (e.g.
 deb files).  Multiple objects can then be combined into
-L<groups|Lintian::Processable::Group>, which Lintian will process
+L<groups|Lintian::Group>, which Lintian will process
 together.
 
 =head1 INSTANCE METHODS
@@ -231,10 +230,6 @@ sub identifier {
 
 =item info
 
-Returns the L<info|Lintian::Collect> object associated with this entry.
-
-Overrides info from L<Lintian::Processable>.
-
 =cut
 
 sub info {
@@ -245,8 +240,6 @@ sub info {
 
 =item clear_cache
 
-Clears any caches held; this includes discarding the L<info|Lintian::Collect> object.
-
 Overrides clear_cache from L<Lintian::Processable>.
 
 =cut
@@ -494,7 +487,7 @@ L<Lintian::Processable::Source>
 
 L<Lintian::Processable::Udeb>
 
-L<Lintian::Processable::Group>
+L<Lintian::Group>
 
 =cut
 
